==> json_dynamic_widget-2.1.0.tar.gz: lib/src/schema/schemas/semantics_schema.dart <==
import 'package:json_theme/json_theme_schemas.dart';

class SemanticsSchema {
  static const id =
      'https://peiffer-innovations.github.io/flutter_json_schemas/schemas/json_dynamic_widget/semantics.json';

  static final schema = {
    r'$schema': 'http://json-schema.org/draft-06/schema#',
    r'$id': '$id',
    r'$comment': 'https://api.flutter.dev/flutter/widgets/Semantics-class.html',
    'type': 'object',
    'title': 'SemanticsBuilder',
    'additionalProperties': false,
    'properties': {
      'button': SchemaHelper.boolSchema,
      'checked': SchemaHelper.boolSchema,
      'container': SchemaHelper.boolSchema,
      'currentValueLength': SchemaHelper.numberSchema,
      'decreasedValue': SchemaHelper.stringSchema,
      'enabled': SchemaHelper.boolSchema,
      'excludeSemantics': SchemaHelper.boolSchema,
      'explicitChildNodes': SchemaHelper.boolSchema,
      'focusable': SchemaHelper.boolSchema,
      'focused': SchemaHelper.boolSchema,
      'header': SchemaHelper.boolSchema,
      'hidden': SchemaHelper.boolSchema,
      'hint': SchemaHelper.stringSchema,
      'image': SchemaHelper.boolSchema,
      'inMutuallyExclusiveGroup': SchemaHelper.boolSchema,
      'increasedValue': SchemaHelper.stringSchema,
      'label': SchemaHelper.stringSchema,
      'link': SchemaHelper.boolSchema,
      'liveRegion': SchemaHelper.boolSchema,
      'maxValueLength': SchemaHelper.numberSchema,
      'multiline': SchemaHelper.boolSchema,
      'namesRoute': SchemaHelper.boolSchema,
      'obscured': SchemaHelper.boolSchema,
      'onCopy': SchemaHelper.stringSchema,
      'onCut': SchemaHelper.stringSchema,
      'onDecrease': SchemaHelper.stringSchema,
      'onDidGainAccessibilityFocus': SchemaHelper.stringSchema,
      'onDidLoseAccessibilityFocus': SchemaHelper.stringSchema,
      'onDismiss': SchemaHelper.stringSchema,
      'onIncrease': SchemaHelper.stringSchema,
      'onLongPress': SchemaHelper.stringSchema,
      'onLongPressHint': SchemaHelper.stringSchema,
      'onMoveCursorBackwardByCharacter': SchemaHelper.stringSchema,
      'onMoveCursorForwardByCharacter': SchemaHelper.stringSchema,
      'onPaste': SchemaHelper.stringSchema,
      'onScrollDown': SchemaHelper.stringSchema,
      'onScrollLeft': SchemaHelper.stringSchema,
      'onScrollRight': SchemaHelper.stringSchema,
      'onScrollUp': SchemaHelper.stringSchema,
      'onSetSelection': SchemaHelper.stringSchema,
      'onTap': SchemaHelper.stringSchema,
      'onTapHint': SchemaHelper.stringSchema,
      'readOnly': SchemaHelper.boolSchema,
      'scopesRoute': SchemaHelper.boolSchema,
      'selected': SchemaHelper.boolSchema,
      'slider': SchemaHelper.boolSchema,
      'sortKey': SchemaHelper.objectSchema(OrdinalSortKeySchema.id),
      'tagForChildren': SchemaHelper.objectSchema(SemanticsTagSchema.id),
      'textDirection': SchemaHelper.objectSchema(TextDirectionSchema.id),
      'textField': SchemaHelper.boolSchema,
      'toggled': SchemaHelper.boolSchema,
      'value': SchemaHelper.stringSchema,
    }
  };
}

==> json_dynamic_widget-3.1.1.tar.gz: lib/src/schema/schemas/semantics_schema.dart <==
import 'package:json_theme/json_theme_schemas.dart';

class SemanticsSchema {
  static const id =
      'https://peiffer-innovations.github.io/flutter_json_schemas/schemas/json_dynamic_widget/semantics.json';

  static final schema = {
    r'$schema': 'http://json-schema.org/draft-06/schema#',
    r'$id': '$id',
    r'$comment': 'https://api.flutter.dev/flutter/widgets/Semantics-class.html',
    'type': 'object',
    'title': 'Semantics',
    'additionalProperties': false,
    'properties': {
      'attributedDecreasedValue': SchemaHelper.stringSchema,
      'attributedHint': SchemaHelper.stringSchema,
      'attributedIncreasedValue': SchemaHelper.stringSchema,
      'attributedLabel': SchemaHelper.stringSchema,
      'attributedValue': SchemaHelper.stringSchema,
      'button': SchemaHelper.boolSchema,
      'customSemanticsActions': SchemaHelper.stringSchema,
      'checked': SchemaHelper.boolSchema,
      'container': SchemaHelper.boolSchema,
      'currentValueLength': SchemaHelper.numberSchema,
      'decreasedValue': SchemaHelper.stringSchema,
      'enabled': SchemaHelper.boolSchema,
      'excludeSemantics': SchemaHelper.boolSchema,
      'explicitChildNodes': SchemaHelper.boolSchema,
      'focusable': SchemaHelper.boolSchema,
      'focused': SchemaHelper.boolSchema,
      'header': SchemaHelper.boolSchema,
      'hidden': SchemaHelper.boolSchema,
      'hint': SchemaHelper.stringSchema,
      'image': SchemaHelper.boolSchema,
      'inMutuallyExclusiveGroup': SchemaHelper.boolSchema,
      'increasedValue': SchemaHelper.stringSchema,
      'keyboardKey': SchemaHelper.boolSchema,
      'label': SchemaHelper.stringSchema,
      'link': SchemaHelper.boolSchema,
      'liveRegion': SchemaHelper.boolSchema,
      'maxValueLength': SchemaHelper.numberSchema,
      'multiline': SchemaHelper.boolSchema,
      'namesRoute': SchemaHelper.boolSchema,
      'obscured': SchemaHelper.boolSchema,
      'onCopy': SchemaHelper.stringSchema,
      'onCut': SchemaHelper.stringSchema,
      'onDecrease': SchemaHelper.stringSchema,
      'onDidGainAccessibilityFocus': SchemaHelper.stringSchema,
      'onDidLoseAccessibilityFocus': SchemaHelper.stringSchema,
      'onDismiss': SchemaHelper.stringSchema,
      'onIncrease': SchemaHelper.stringSchema,
      'onLongPress': SchemaHelper.stringSchema,
      'onLongPressHint': SchemaHelper.stringSchema,
      'onMoveCursorBackwardByCharacter': SchemaHelper.stringSchema,
      'onMoveCursorForwardByCharacter': SchemaHelper.stringSchema,
      'onPaste': SchemaHelper.stringSchema,
      'onScrollDown': SchemaHelper.stringSchema,
      'onScrollLeft': SchemaHelper.stringSchema,
      'onScrollRight': SchemaHelper.stringSchema,
      'onScrollUp': SchemaHelper.stringSchema,
      'onSetSelection': SchemaHelper.stringSchema,
      'onTap': SchemaHelper.stringSchema,
      'onTapHint': SchemaHelper.stringSchema,
      'readOnly': SchemaHelper.boolSchema,
      'scopesRoute': SchemaHelper.boolSchema,
      'selected': SchemaHelper.boolSchema,
      'slider': SchemaHelper.boolSchema,
      'sortKey': SchemaHelper.objectSchema(OrdinalSortKeySchema.id),
      'tagForChildren': SchemaHelper.objectSchema(SemanticsTagSchema.id),
      'textDirection': SchemaHelper.objectSchema(TextDirectionSchema.id),
      'textField': SchemaHelper.boolSchema,
      'toggled': SchemaHelper.boolSchema,
      'value': SchemaHelper.stringSchema,
    }
  };
}
